import { SFCDescriptor, SFCScriptBlock } from './parse';
import { ParserPlugin } from '@babel/parser';
import { Node, Identifier } from '@babel/types';
import { SFCTemplateCompileOptions } from './compileTemplate';
export interface SFCScriptCompileOptions {
    /**
     * Scope ID for prefixing injected CSS varialbes.
     * This must be consistent with the `id` passed to `compileStyle`.
     */
    id: string;
    /**
     * Production mode. Used to determine whether to generate hashed CSS variables
     */
    isProd?: boolean;
    /**
     * https://babeljs.io/docs/en/babel-parser#plugins
     */
    babelParserPlugins?: ParserPlugin[];
    /**
     * Enable ref: label sugar
     * https://github.com/vuejs/rfcs/pull/228
     * @default true
     */
    refSugar?: boolean;
    /**
     * Compile the template and inline the resulting render function
     * directly inside setup().
     * - Only affects <script setup>
     * - This should only be used in production because it prevents the template
     * from being hot-reloaded separately from component state.
     */
    inlineTemplate?: boolean;
    /**
     * Options for template compilation when inlining. Note these are options that
     * would normally be pased to `compiler-sfc`'s own `compileTemplate()`, not
     * options passed to `compiler-dom`.
     */
    templateOptions?: Partial<SFCTemplateCompileOptions>;
    /**
     * Skip codegen and only return AST / binding / text range information.
     * Also makes the call error-tolerant.
     * Used for IDE support.
     */
    parseOnly?: boolean;
}
/**
 * Compile `<script setup>`
 * It requires the whole SFC descriptor because we need to handle and merge
 * normal `<script>` + `<script setup>` if both are present.
 */
export declare function compileScript(sfc: SFCDescriptor, options: SFCScriptCompileOptions): SFCScriptBlock;
/**
 * Walk an AST and find identifiers that are variable references.
 * This is largely the same logic with `transformExpressions` in compiler-core
 * but with some subtle differences as this needs to handle a wider range of
 * possible syntax.
 */
export declare function walkIdentifiers(root: Node, onIdentifier: (node: Identifier, parent: Node, parentStack: Node[]) => void): void;
//# sourceMappingURL=compileScript.d.ts.map