import { ElementNode, SourceLocation, CompilerError, BindingMetadata } from '@vue/compiler-core';
import { RawSourceMap } from 'source-map';
import { TemplateCompiler } from './compileTemplate';
import { Statement } from '@babel/types';
export interface SFCParseOptions {
    filename?: string;
    sourceMap?: boolean;
    sourceRoot?: string;
    pad?: boolean | 'line' | 'space';
    compiler?: TemplateCompiler;
}
export interface SFCBlock {
    type: string;
    content: string;
    attrs: Record<string, string | true>;
    loc: SourceLocation;
    map?: RawSourceMap;
    lang?: string;
    src?: string;
}
export interface SFCTemplateBlock extends SFCBlock {
    type: 'template';
    ast: ElementNode;
}
export interface SFCScriptBlock extends SFCBlock {
    type: 'script';
    setup?: string | boolean;
    bindings?: BindingMetadata;
    scriptAst?: Statement[];
    scriptSetupAst?: Statement[];
    ranges?: ScriptSetupTextRanges;
}
/**
 * Text range data for IDE support
 */
export interface ScriptSetupTextRanges {
    scriptBindings: TextRange[];
    scriptSetupBindings: TextRange[];
    propsTypeArg?: TextRange;
    propsRuntimeArg?: TextRange;
    emitsTypeArg?: TextRange;
    emitsRuntimeArg?: TextRange;
    withDefaultsArg?: TextRange;
}
export interface TextRange {
    start: number;
    end: number;
}
export interface SFCStyleBlock extends SFCBlock {
    type: 'style';
    scoped?: boolean;
    module?: string | boolean;
}
export interface SFCDescriptor {
    filename: string;
    source: string;
    template: SFCTemplateBlock | null;
    script: SFCScriptBlock | null;
    scriptSetup: SFCScriptBlock | null;
    styles: SFCStyleBlock[];
    customBlocks: SFCBlock[];
    cssVars: string[];
    slotted: boolean;
}
export interface SFCParseResult {
    descriptor: SFCDescriptor;
    errors: (CompilerError | SyntaxError)[];
}
export declare function parse(source: string, { sourceMap, filename, sourceRoot, pad, compiler }?: SFCParseOptions): SFCParseResult;
//# sourceMappingURL=parse.d.ts.map