import { ConcreteComponent, Data, Component, ComponentInternalInstance } from './component';
import { ComponentOptions, MergedComponentOptions, RuntimeCompilerOptions } from './componentOptions';
import { ComponentPublicInstance } from './componentPublicInstance';
import { Directive } from './directives';
import { RootRenderFunction } from './renderer';
import { InjectionKey } from './apiInject';
import { RootHydrateFunction } from './hydration';
import { NormalizedPropsOptions } from './componentProps';
import { ObjectEmitsOptions } from './componentEmits';
export interface App<HostElement = any> {
    version: string;
    config: AppConfig;
    use(plugin: Plugin, ...options: any[]): this;
    mixin(mixin: ComponentOptions): this;
    component(name: string): Component | undefined;
    component(name: string, component: Component): this;
    directive(name: string): Directive | undefined;
    directive(name: string, directive: Directive): this;
    mount(rootContainer: HostElement | string, isHydrate?: boolean, isSVG?: boolean): ComponentPublicInstance;
    unmount(): void;
    provide<T>(key: InjectionKey<T> | string, value: T): this;
    _uid: number;
    _component: ConcreteComponent;
    _props: Data | null;
    _container: HostElement | null;
    _context: AppContext;
    _instance: ComponentInternalInstance | null;
    /**
     * v2 compat only
     */
    filter?(name: string): Function | undefined;
    filter?(name: string, filter: Function): this;
    /**
     * @internal v3 compat only
     */
    _createRoot?(options: ComponentOptions): ComponentPublicInstance;
}
export declare type OptionMergeFunction = (to: unknown, from: unknown) => any;
export interface AppConfig {
    readonly isNativeTag?: (tag: string) => boolean;
    performance: boolean;
    optionMergeStrategies: Record<string, OptionMergeFunction>;
    globalProperties: Record<string, any>;
    errorHandler?: (err: unknown, instance: ComponentPublicInstance | null, info: string) => void;
    warnHandler?: (msg: string, instance: ComponentPublicInstance | null, trace: string) => void;
    /**
     * @deprecated use config.compilerOptions.isCustomElement
     */
    isCustomElement?: (tag: string) => boolean;
    /**
     * Options to pass to @vue/compiler-dom.
     * Only supported in runtime compiler build.
     */
    compilerOptions: RuntimeCompilerOptions;
}
export interface AppContext {
    app: App;
    config: AppConfig;
    mixins: ComponentOptions[];
    components: Record<string, Component>;
    directives: Record<string, Directive>;
    provides: Record<string | symbol, any>;
    /**
     * Cache for merged/normalized component options
     * Each app instance has its own cache because app-level global mixins and
     * optionMergeStrategies can affect merge behavior.
     * @internal
     */
    optionsCache: WeakMap<ComponentOptions, MergedComponentOptions>;
    /**
     * Cache for normalized props options
     * @internal
     */
    propsCache: WeakMap<ConcreteComponent, NormalizedPropsOptions>;
    /**
     * Cache for normalized emits options
     * @internal
     */
    emitsCache: WeakMap<ConcreteComponent, ObjectEmitsOptions | null>;
    /**
     * HMR only
     * @internal
     */
    reload?: () => void;
    /**
     * v2 compat only
     * @internal
     */
    filters?: Record<string, Function>;
}
declare type PluginInstallFunction = (app: App, ...options: any[]) => any;
export declare type Plugin = PluginInstallFunction & {
    install?: PluginInstallFunction;
} | {
    install: PluginInstallFunction;
};
export declare function createAppContext(): AppContext;
export declare type CreateAppFunction<HostElement> = (rootComponent: Component, rootProps?: Data | null) => App<HostElement>;
export declare function createAppAPI<HostElement>(render: RootRenderFunction, hydrate?: RootHydrateFunction): CreateAppFunction<HostElement>;
export {};
//# sourceMappingURL=apiCreateApp.d.ts.map